################################################################################
#    (A)GIS: A Geophysical Information System. Using GMT and Tcl/Tk to map     #
#               geophysical data sets.                                         #
#                                                                              #
#    Copyright (C) 1998  Thorsten W. Becker, Alexander Braun                   #
#                                                                              #
#    This program is free software; you can redistribute it and/or modify      #
#    it under the terms of the GNU General Public License as published by      #
#    the Free Software Foundation; either version 2 of the License, or         #
#    (at your option) any later version.                                       #
#                                                                              #
#    This program is distributed in the hope that it will be useful,           #
#    but WITHOUT ANY WARRANTY; without even the implied warranty of            #
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             #
#    GNU General Public License for more details.                              #
#                                                                              #
#                                                                              #
#    You should have received a copy of the GNU General Public License         #
#    along with this program; see the file COPYING.  If not, write to          #
#    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,          #
#    Boston, MA 02111-1307, USA.                                               #
#                                                                              #
################################################################################

# agis.tcl -- main procedure
#
# part of the (A)GIS package
#

################################################################################
#
#                                  (A)GIS, version 0.5
#
# graphical user interface for the GMT tools
# interface to various datasets 
#
# documentation in manual.ps
#
# modify variables such as path names in agis_configure.tcl
#
#
# Thorsten Becker, becker@eps.harvard.edu
# May 1998
#
################################################################################

# load the default settings and all the global variables
source "$env(agis_root)/agis_configure.tcl"

# source some site specific settings that may overwrite the defaults in a
# agis_configure (so agis_configure needn't be changed, if the file is not
# there, ignore the error message

catch { source "$env(agis_root)/agis_siteconfig.tcl" }

# check the availability of at least one GMT command

if { [catch "[ list exec [ format %sgmtdefaults $gmtbins ] -L ]" var ] } {
    puts "(A)GIS: Can't execute \"[ format %sgmtdefaults $gmtbins ]\" !"
    puts "(A)GIS: The GMT commands are probably in the wrong place"
    puts "(A)GIS: or not in your path."
    puts "(A)GIS: Modify $agis_root/agis_configure.tcl, "
    puts "(A)GIS: $agis_root/agis_siteconfig.tcl or your \$path variable."
    exit -1 
}
if { ([ catch "[ list exec which $ps_to_gif_converter ]" tmp_var ])||([ string range $tmp_var  0 1 ] == "no") } {
    puts "(A)GIS: Couldn't check the path to the default converter,"
    puts "(A)GIS: \"$ps_to_gif_converter\". This means that you are probably now"
    puts "(A)GIS: restricted to the postscript features."

}


#global frame starts here
wm title . "(A)GIS version 0.5"

# load various input/output routines 
source "$env(agis_root)/agis_iomisc.tcl"

# call the init routine
source "$env(agis_root)/agis_init.tcl"   
     
# set up the menu bar with sub menus
source "$env(agis_root)/agis_menus.tcl"       

# load the plotting related routines
source "$env(agis_root)/agis_plotting.tcl"

# load the dialogs related to changing parameters
source "$env(agis_root)/agis_parameters.tcl"

# load the dialogs realted to dataset selection
source "$env(agis_root)/agis_datasets.tcl"


################################################################################
# title line

label .msg -textvariable headermessage
.msg config -bg PeachPuff1
pack .msg -fill x
pack .msg .mb -side top -fill x


if { $changed_gmtdefaults == "moved" } {
    
    # remind the user here if the $env(PWD)/.gmtdefaults file was changed
    # (because we want to have something  on the screen first )

    set warningstring "The .gmtdefaults file in our working directory \"$env(PWD)\""
    set warningstring "$warningstring is different from the GMT 3.0 default.\n\nSince these settings are "
    set warningstring "$warningstring preferred by (A)GIS, your file was temporarily moved to"
    set warningstring "$warningstring TEMPORARILY_MOVED_GMT_DEFAULT.\n\nIf (and only if) "
    set warningstring "$warningstring (A)GIS terminates abnormally you might have to copy it back yourself!"
    if { $changed_gmtdefaults != "0" } { dialog .d {.gmtdefaults handling} $warningstring warning 0 {OK} }
}

################################################################################
# check the availability of data files
set files_unavailable ""

if { [ catch { exec test -s $gtopodata } ] } { set files_unavailable "$files_unavailable\n$gtopodata\n" }
if { [ catch { exec test -s $agedata   } ] } { set files_unavailable "$files_unavailable\n$agedata\n" }
if { [ catch { exec test -s $freeair_grav_data } ] } { set files_unavailable "$files_unavailable\n$freeair_grav_data"}
if { [ catch { exec test -s $geoid_data} ] } { set files_unavailable "$files_unavailable\n$geoid_data"}
if { [ catch { exec test -s $xysize_data(1)} ] } { set files_unavailable "$files_unavailable\n$xysize_data(1)"}
if { [ catch { exec test -s $xysize_data(2)} ] } { set files_unavailable "$files_unavailable\n$xysize_data(2)"}
if { [ string trim $files_unavailable ] != "" } {
     dialog .d {Missing data sets...} \
	"The following data sets are unavailable:\n\n$files_unavailable\n\nThis means that some of the data handling routines will not work. Change the agis_configure.tcl file to the correct filenames or create a agis_siteconfig.tcl file."  warning 0 {OK} 
}




################################################################################
# display the map in the lower part as a GIF image

# copy the default image to fill the frame the first time if there is
# no temporary file around

exec $agis_root/agis_helper_checkfile $gif_filename $def_gif_filename

image create photo map_image -file $gif_filename
label .mapimage -image  map_image  -bd 1 -relief sunken
pack .mapimage
pack .mb .mapimage -fill x -fill y -side top



puts "(A)GIS: Initialization complete. If quitting (A)GIS"
puts "(A)GIS: doesn't seem to work, try pressing \"RETURN\""
puts "(A)GIS: in this shell window."

