################################################################################
#    (A)GIS: A Geophysical Information System. Using GMT and Tcl/Tk to map     #
#               geophysical data sets.                                         #
#                                                                              #
#    Copyright (C) 1998  Thorsten W. Becker, Alexander Braun                   #
#                                                                              #
#    This program is free software; you can redistribute it and/or modify      #
#    it under the terms of the GNU General Public License as published by      #
#    the Free Software Foundation; either version 2 of the License, or         #
#    (at your option) any later version.                                       #
#                                                                              #
#    This program is distributed in the hope that it will be useful,           #
#    but WITHOUT ANY WARRANTY; without even the implied warranty of            #
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             #
#    GNU General Public License for more details.                              #
#                                                                              #
#                                                                              #
#    You should have received a copy of the GNU General Public License         #
#    along with this program; see the file COPYING.  If not, write to          #
#    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,          #
#    Boston, MA 02111-1307, USA.                                               #
#                                                                              #
################################################################################

################################################################################
# agis_configure.tcl -- global variables and default settings
# change path names and other things here, not anywhere else
# 
# global variables were chosen for simplicity, so if you introduce new ones
# check here
#
# part of the (A)GIS package
#
################################################################################


################################################################################
# path issues and filenames 
################################################################################

# find the (A)GIS distribution here

set agis_root $env(agis_root)


# let user be the user's name for temporary files

if { [ catch { set user $env(USER) } ] } {
    if { [ catch { exec id -un } user ]} {
	puts "(A)GIS: Couldn't determine the user's name, neither"
	puts "(A)GIS: \$USER was set or \"id -un\" worked."
	puts "(A)GIS: Since the user name is used for tmp files,"
	puts "(A)GIS: Exit here."
	exit
    }
}

# set gmtbins to the path of the gmt commands if they are not in
# the shell search path, else use ""

set gmtbins ""


# the shell we use for scripting should be the korn shell
# otherwise you have to modify some commands in the helper apps

set shell_to_use "\#!/bin/ksh"

# change this for the default location to put the script file (A)GIS creates

set agis_files_are_in "$env(PWD)"

# default startup image

set def_gif_filename "$agis_root/agis_def.gif"

# default file to save plotting parameters in

set parameter_filename "$agis_files_are_in/agis_parameters.dat"

# temporary file names, we need some user specific name else 
# problems with permissions would arise
# if you change the default location from /tmp/agis_*
# you might have to take care to remove the temporary files yourself
#

set ps_filename [ format /tmp/agis_%s_tmp.ps $user ]

# change this line for instance to 
# set gif_filename [ format /tmp/agis_%s_tmp.ppm $user ]
# if you want (A)GIS and convert to work with ppm files instead
set gif_filename [ format /tmp/agis_%s_tmp.gif $user ]

set grid_filename [ format /tmp/agis_%s_grd $user ]
set shade_filename [ format /tmp/agis_%s_shade $user ]

# file to save the GMT script commands in

set batchfile "$agis_files_are_in/agis_commands.gmt"

# file to store the GMT errors

set batcherr [ format /tmp/agis_%s_gmt_err.txt $user ]


################################################################################
# tool commands for postscript viewing and converting
################################################################################

# postscript viewer

set psviewer "showps"


# command line for viewing a postscript file in portrait orientation

set psviewer_command_portrait "$psviewer -or portrait"

# what command line parameter switches to a rotated view ?

set psviewer_command_landscape "$psviewer -or landscape"

# for using ghostview add the following lines (without the comment sign "#") in
#  your agis_siteconfig.tcl file

# set psviewer "ghostview"

# for ghostviewv you would furthermore add

# set psviewer_command_portrait "$psviewer -portrait"
# set psviewer_command_landscape "$psviewer -landscape"

# or the gs equivalent

# set psviewer_command_portrait "$psviewer -q"
# set psviewer_command_landscape "$psviewer -q"



# PS to GIF converter

set ps_to_gif_converter "convert"
set converter_rotate_command "-rotate"

set ps_to_gif_command_portrait "$ps_to_gif_converter $converter_rotate_command   0 $ps_filename $gif_filename"
set ps_to_gif_command_landscape "$ps_to_gif_converter $converter_rotate_command  90 $ps_filename $gif_filename"

# for using gs instead of convert put the next four lines (or something like them)
#  in your agis_siteconfig.tcl file (this assumes that you have the gif conversion included in
#  your compilation of ghostscript, if not (for copyright reasons) use "ppmraw" instead of "gif8")
# set ps_to_gif_converter "gs"
# set ps_to_gif_command "$ps_to_gif_converter -q -sDEVICE=gif8 -sOutputFile=$gif_filename - < $ps_filename 2> /dev/null"
# set ps_to_gif_command_portrait $ps_to_gif_command
# set ps_to_gif_command_landscape $ps_to_gif_command 




################################################################################
# generic GMT scripting defaults 
################################################################################

# set this to "-V" for verbose GMT messages

set verbose "-V"

# where do I find the colormaps 

set colorpath "$agis_root/colormaps"

# set this to 1 to use pstext for plot titles instead of the -B option 

    
set use_pstext_for_title 0


# title for the plot

set plot_title ""
set title_font_size 24

# GMT font numbers

set title_font 1 

# see the pstext -L command:
#         Font #  Font Name
#         ------------------------------------
#           0     Helvetica
#           1     Helvetica-Bold
#           2     Helvetica-Oblique
#           3     Helvetica-BoldOblique
#           4     Times-Roman
#           5     Times-Bold
#           6     Times-Italic
#           7     Times-BoldItalic
#           8     Courier
#           9     Courier-Bold
#          10     Courier-Oblique
#          11     Courier-BoldOblique
#          12     Symbol
#          13     AvantGarde-Book
#          14     AvantGarde-BookOblique
#          15     AvantGarde-Demi
#          16     AvantGarde-DemiOblique
#          17     Bookman-Demi
#          18     Bookman-DemiItalic
#          19     Bookman-Light
#          20     Bookman-LightItalic
#          21     Helvetica-Narrow
#          22     Helvetica-Narrow-Bold
#          23     Helvetica-Narrow-Oblique
#          24     Helvetica-Narrow-BoldOblique
#          25     NewCenturySchlbk-Roman
#          26     NewCenturySchlbk-Italic
#          27     NewCenturySchlbk-Bold
#          28     NewCenturySchlbk-BoldItalic
#          29     Palatino-Roman
#          30     Palatino-Italic
#          31     Palatino-Bold
#          32     Palatino-BoldItalic
#          33     ZapfChancery-MediumItalic


################################################################################
# raster datasets settings
################################################################################

# raster data set number  to start with
# described below

set raster_dataset 1

# set principal data path if any

set rasterpath "/wrk/arthur/becker/global_data"

# resolution in arc minutes for the raster data sets

set raster_resolution 60

# legend beneath the raster plots

set legend 1

# shading using grdgradient

set shading 1


################################################################################
# dataset one means pscoast

# colors for pscoast

set land_color(1) 0 ; set land_color(2) 200 ;  set land_color(3) 0
set sea_color(1) 0 ; set sea_color(2) 0 ; set sea_color(3) 200
set river_color(1) 0 ; set river_color(2) 0 ; set river_color(3) 255 ;

# pscoast options to start with

set resolution "c"
set shoreline 0
set river(1) 0 ; set river(2) 0 ; set river(3) 0 ; set river(4) 0
set linewidth(1) 1

# additions to the pscoast line

set pscoast_add ""


# ETOPO5 is plotted by using grdraster, so options here for data set two


################################################################################
# GTOPO 30, data set three

# colormap for the topography datasets
set topocolor "$colorpath/topo.cpt"

# where find the Smith&Sandwell/GTOPO30 data set?
set gtopodata "$rasterpath/gtopo30/topo_6.2.img"

################################################################################
# sea floor age, data set four

# colormap for seafloor age
set agecolor "$colorpath/seafloor_age.cpt"
# which seafloor age dataset should be used ?
set agedata "$rasterpath/seafloor_age/globalage_1.3.grd"

################################################################################
# gravity, data set five

# colormap for gravity
set gravitycolor "$colorpath/gravity.cpt"

# which gravity dataset for the free air gravity over sea?

set freeair_grav_data "$rasterpath/gravity/world_grav.img.7.2"



################################################################################
# Geoid data grd file

set geoid_data "$rasterpath/geoid/osu91a1f.grd"
set geoidcolor "$colorpath/geoid.cpt"



################################################################################
#

set custom_raster_data $agedata



################################################################################
# polygon data stuff
################################################################################

################################################################################
# data set one, plate boundaries

# default setting for plotting is off, change to 1 when the data set should 
# be shown from scratch

set polygon_dataset(1) 0 

# location of the polygon data

set plate_boundary_data(1) "$agis_root/nuvel.yx"

# colorsettings

set plate_color(1) 255 ; set plate_color(2) 255 ; set plate_color(3) 255

# guess what
set linewidth(3) 3



################################################################################
# data set two, significant eathquakes as provided by NDGC


# same as for polygon data set 1 

set polygon_dataset(2) 0 
# symbol sizes are in fractions of the mapwidth

#dummy
set symbol_size(1) 0.0 
#earthquakes
set symbol_size(2) 0.0005
set xysize_data(1) "$rasterpath/quakes/significant_ngdc.dat"
set quake1_color(1) 0 ; set quake1_color(2) 0 ; set quake1_color(3) 0
# default symbol
set symbol(1) "a" 

################################################################################
# data set three, hypocenter data from USGS/NEIC


# same settings as for data set 2
set polygon_dataset(3) 0
set symbol_size(3) 0.0005
set xysize_data(2) "$rasterpath/quakes/usgs_neic.dat"
set quake2_color(1) 0 ; set quake2_color(2) 0 ; set quake2_color(3) 0
set symbol(2) "c"



################################################################################
# custom data set one starts here

#same as above for 3

set polygon_dataset(4) 0
set custom1_color(1) 0 ; set custom1_color(2) 0 ; set custom1_color(3) 0
set symbol(3) "c"
set symbol_size(4) 0.05

# the following parameters can be set in the Datasets/Parameters custom xys menu
# plotting parameters for awk
set custom1(1) 1 ; set custom1(2) 2 ; set custom1(3) 3; set custom1(4) 0.05

# filename for the custom xys data file one
set custom1(5) ""

################################################################################
# custom data set two starts here, same as for custom one

set polygon_dataset(5) 0
set symbol_size(5) 0.05
set custom2_color(1) 0 ; set custom2_color(2) 0 ; set custom2_color(3) 0
set symbol(4) "c"
# plotting parameters for awk
set custom2(1) 1 ; set custom2(2) 2 ; set custom2(3) 3; set custom2(4) 0.05
# filename for the custom xys data file one
set custom2(5) ""





################################################################################
# CMT solutions

set polygon_dataset(6) 0

set cmtdata "$agis_root/01_02-98.cmt"
set quake3_color(1) 0 ; set quake3_color(2) 0 ; set quake3_color(3) 0

set symbol_size(6) 0.02


################################################################################
# Hot spots of Steinberger

set polygon_dataset(7) 0

set hotspotdata "$agis_root/hotspots.dat"
set quake4_color(1) 255 ; set quake4_color(2) 0 ; set quake4_color(3) 0
set hotspot_nametag 1
set symbol(5) "a"
set symbol_size(7) 0.005

################################################################################
# volcanoes from the Smithsonian institution, http://www.volcano.si.edu/gvp/volcdata/index.htm

set polygon_dataset(8) 0

set volcanodata "$agis_root/volcanoes.dat"
set quake5_color(1) 255 ; set quake5_color(2) 0 ; set quake5_color(3) 0
set volcano_nametag 0
set symbol(6) "a"
set symbol_size(8) 0.005



################################################################################
# startup values for mapping stuff
################################################################################

# starting boundaries for the geographic region

set north 10.0
set south -10.0
set east 10.0
set west -10.0

# map center for whole earth plots

set lat0 0
set lon0 0

# startup projection

set proj(1) "M"

# latitudinal limits for the Mercator projection

set mercatorlimit(1) 75
set mercatorlimit(2) -75

# default custom projection

set custom_projection "-JX10"

set boundary(1) 0 ; set boundary(2) 0
set linewidth(2) 3


#map tick intervals x and y axis

set ticks(1) 6 ; set ticks(2) 6

set gridlines 0

set annotation 1


set mapscale 0

# papersize x y in inches, use 8.5 and 11 for letter
#  or 8 and 10 for A4

set papersize(1) 8.5 ; set papersize(2) 11

# page orientation, 0 means landscape

set portrait 1


# x offset for postscript plot

set ps_offset(1) 1.0

# y offset

set ps_offset(2) 1.0

# GMT logo is off by default since it would interfere with the colorbars

set show_gmt_logo 0



################################################################################
# misc. global variables not to be changed by the user
# in the first place
################################################################################


# this is set to zero when parameters 

set saved 1

set headermessage "(A)GIS"

# this will be the batch jobs process id, now its (A)GIS'

set batch_pid [ pid ]


# colormap to begin with, can be changed by user and
# is adjusted when the raster data set is changed.

set colormap  $topocolor
